![python version](https://img.shields.io/pypi/pyversions/fastapi_template?style=flat-square) ![Build status](https://img.shields.io/github/workflow/status/s3rius/FastAPI-template/Release%20python%20package?style=flat-square) [![version](https://img.shields.io/pypi/v/fastapi_template?style=flat-square)](https://pypi.org/project/fastapi-template/)

<div align="center">
<img src="https://raw.githubusercontent.com/s3rius/FastAPI-template/master/images/logo.png" width=700>
<div><i>Fast and flexible general-purpose template for your API.</i></div>
</div>


## Usage
⚠️ [Git](https://git-scm.com/downloads), [Python](https://www.python.org/), and [Docker-compose](https://docs.docker.com/compose/install/) must be installed and accessible ⚠️

```bash
python3 -m pip install fastapi_template
fastapi_template
# Answer prompts questions
# ???
# 🍪 Enjoy your new project 🍪
cd new_project
docker-compose up --build
```

## Features
Currently supported features:
- redis
- systemd units
- Example (dummy) SQLAlchemy model
- Elastic Search support
- Scheduler support
